# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v3.25.1~d08f18d',
    built_at='2023-08-10 16:31:46Z',
    sha='d08f18d978271c6a560d2b92e64e96e24f31fa5b',
    branch='HEAD',
    tag='v3.25.1',
)
